@@ -14,15 +14,16 @@ module Crypto.PubKey.DH
     , SharedKey
     , generateParams
     , generatePrivate
+    , calculatePublic
     , generatePublic
     , getShared
     ) where
 
-import Crypto.Number.ModArithmetic (exponantiation)
+import Crypto.Number.ModArithmetic (expSafe)
 import Crypto.Number.Prime (generateSafePrime)
-import Crypto.Number.Generate (generateOfSize)
+import Crypto.Number.Generate (generateMax)
 import Crypto.Types.PubKey.DH
-import Crypto.Random.API
+import Crypto.Random
 import Control.Arrow (first)
 
 -- | generate params from a specific generator (2 or 5 are common values)
@@ -33,14 +34,22 @@ generateParams rng bits generator =
 
 -- | generate a private number with no specific property
 -- this number is usually called X in DH text.
-generatePrivate :: CPRG g => g -> Int -> (PrivateNumber, g)
-generatePrivate rng bits = first PrivateNumber $ generateOfSize rng bits
+generatePrivate :: CPRG g => g -> Params -> (PrivateNumber, g)
+generatePrivate rng (Params p _) = first PrivateNumber $ generateMax rng p
 
--- | generate a public number that is for the other party benefits.
+-- | calculate the public number from the parameters and the private key
 -- this number is usually called Y in DH text.
+calculatePublic :: Params -> PrivateNumber -> PublicNumber
+calculatePublic (Params p g) (PrivateNumber x) = PublicNumber $ expSafe g x p
+
+-- | calculate the public number from the parameters and the private key
+-- this number is usually called Y in DH text.
+--
+-- DEPRECATED use calculatePublic
 generatePublic :: Params -> PrivateNumber -> PublicNumber
-generatePublic (Params p g) (PrivateNumber x) = PublicNumber $ exponantiation g x p
+generatePublic = calculatePublic
+-- commented until 0.3 {-# DEPRECATED generatePublic "use calculatePublic" #-}
 
 -- | generate a shared key using our private number and the other party public number
 getShared :: Params -> PrivateNumber -> PublicNumber -> SharedKey
-getShared (Params p _) (PrivateNumber x) (PublicNumber y) = SharedKey $ exponantiation y x p
+getShared (Params p _) (PrivateNumber x) (PublicNumber y) = SharedKey $ expSafe y x p
