@@ -1,11 +1,9 @@
 {-# LANGUAGE OverloadedStrings #-}
 module KAT where
 
-import Test.Framework (Test, defaultMain, testGroup)
-import Test.Framework.Providers.HUnit (testCase)
-import Test.QuickCheck
-import Test.QuickCheck.Test
-import Test.HUnit
+import Test.Tasty
+import Test.Tasty.HUnit
+import Test.Tasty.QuickCheck
 import System.IO (hFlush, stdout)
 
 import Data.ByteString (ByteString)
@@ -19,6 +17,7 @@ import qualified Crypto.Hash.SHA1 as SHA1
 import KAT.OAEP
 import KAT.PSS
 import KAT.DSA
+import KAT.ECC
 import KAT.ECDSA
 
 data VectorMgf = VectorMgf { seed :: ByteString
@@ -40,5 +39,8 @@ katTests =
     , pssTests
     , oaepTests
     , dsaTests
+    , eccTests
     , ecdsaTests
     ]
+
+newKats = [ eccKatTests ]
